@@ -223,7 +223,6 @@ void EntityTreeView::setModel( QAbstractItemModel * model )
            SLOT(slotSelectionChanged(QItemSelection,QItemSelection)) );
 }
 
-
 void EntityTreeView::timerEvent( QTimerEvent *event )
 {
   if ( event->timerId() == d->mDragExpandTimer.timerId() ) {
@@ -287,6 +286,11 @@ void EntityTreeView::setXmlGuiClient( KXMLGUIClient * xmlGuiClient )
   d->mXmlGuiClient = xmlGuiClient;
 }
 
+KXMLGUIClient *EntityTreeView::xmlGuiClient() const
+{
+  return d->mXmlGuiClient;
+}
+
 #ifndef QT_NO_DRAGANDDROP
 void EntityTreeView::startDrag( Qt::DropActions supportedActions )
 {
@@ -294,7 +298,6 @@ void EntityTreeView::startDrag( Qt::DropActions supportedActions )
 }
 #endif
 
-
 void EntityTreeView::setDropActionMenuEnabled( bool enabled )
 {
 #ifndef QT_NO_DRAGANDDROP
@@ -332,5 +335,4 @@ void EntityTreeView::setDefaultPopupMenu( const QString &name )
   d->mDefaultPopupMenu = name;
 }
 
-
 #include "moc_entitytreeview.cpp"
