@@ -295,6 +295,20 @@ class AKONADI_EXPORT Item : public Entity
      */
     QString mimeType() const;
 
+    /**
+     * Sets the @p gid of the entity.
+     *
+     * @since 4.12
+     */
+    void setGid( const QString &gid );
+
+    /**
+     * Returns the gid of the entity.
+     *
+     * @since 4.12
+     */
+    QString gid() const;
+
     /**
      * Returns a list of metatype-ids, describing the different
      * variants of payload that are currently contained in this item.
@@ -491,7 +505,6 @@ class AKONADI_EXPORT Item : public Entity
     AKONADI_DECLARE_PRIVATE( Item )
 };
 
-
 template <typename T>
 T Item::payload() const
 {
@@ -564,7 +577,9 @@ Item::tryToClone( T * ret, const int * ) const
           std::auto_ptr<PayloadBase> npb( new Payload<T>( nt ) );
           addPayloadBaseVariant( PayloadType::sharedPointerId, metaTypeId, npb  );
           // and return it
-          if ( ret ) *ret = nt;
+          if ( ret ) {
+            *ret = nt;
+          }
           return true;
       }
   }
