@@ -29,10 +29,10 @@
 #include "itemfetchscope.h"
 #include "job.h"
 #include <akonadi/private/notificationmessagev2_p.h>
-#include "notificationsourceinterface.h"
 #include "entitycache_p.h"
 #include "servermanager.h"
 #include "changenotificationdependenciesfactory_p.h"
+#include "notificationsource_p.h"
 
 #include <kmimetype.h>
 
@@ -60,7 +60,7 @@ class AKONADI_TESTS_EXPORT MonitorPrivate
     Monitor *q_ptr;
     Q_DECLARE_PUBLIC( Monitor )
     ChangeNotificationDependenciesFactory *dependenciesFactory;
-    QObject* notificationSource;
+    NotificationSource* notificationSource;
     Collection::List collections;
     QSet<QByteArray> resources;
     QSet<Item::Id> items;
@@ -94,7 +94,7 @@ class AKONADI_TESTS_EXPORT MonitorPrivate
 
     // Virtual so it can be overridden in FakeMonitor.
     virtual bool connectToNotificationManager();
-    bool acceptNotification( const NotificationMessageV2 &msg, bool allowModifyFlagsConversion = false ) const;
+    bool acceptNotification( const NotificationMessageV2 &msg ) const;
     void dispatchNotifications();
     void flushPipeline();
 
@@ -170,7 +170,7 @@ class AKONADI_TESTS_EXPORT MonitorPrivate
 
       Check whether a Collection is buffered using the isBuffered method.
     */
-    class PurgeBuffer
+    class AKONADI_TESTS_EXPORT PurgeBuffer
     {
       // Buffer the most recent 10 unreferenced Collections
       static const int MAXBUFFERSIZE = 10;
@@ -202,7 +202,6 @@ class AKONADI_TESTS_EXPORT MonitorPrivate
       QQueue<Collection::Id> m_buffer;
     } m_buffer;
 
-
     QHash<Collection::Id, int> refCountMap;
     bool useRefCounting;
     void ref( Collection::Id id );
