@@ -23,7 +23,8 @@
 #include <krandom.h>
 #include <kcomponentdata.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <kglobal.h>
+#include <klocalizedstring.h>
 #include <kstandarddirs.h>
 
 #include <QtCore/QFile>
