@@ -21,7 +21,7 @@
 #include <kcomponentdata.h>
 #include <kdebug.h>
 #include <kglobal.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 #include <kio/ioslave_defaults.h>
 
